Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ApplyResource ¶
ApplyResource handle the http request for applying a new task. it return immediately after the task created into database with status staging.
func GetCmakeArgs ¶
GetCmakeArgs handle the http request for getting the cmake args according to send project message to distcc engine.
func InitStorage ¶
func InitStorage() (err error)
InitStorage let outside be able to init the default manager. it should be called after the manager is created, and before the http-handler start working.
func QueryTaskInfo ¶
QueryTaskInfo handle the http request for querying a existing task
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.